<p class="logo">
  <a href="{{ pathto(master_doc) }}">
    <img class="logo" src="{{ pathto('_static/requests-sidebar.png', 1) }}" alt="Requests logo" />
  </a>
</p>

<p>
  <iframe src="https://ghbtns.com/github-btn.html?user=psf&repo=requests&type=watch&count=true&size=large"
    allowtransparency="true" frameborder="0" scrolling="0" width="200px" height="35px"></iframe>
</p>

<p>
  Requests is an elegant and simple HTTP library for Python, built for
  human beings.
</p>

<h3>Useful Links</h3>
<ul>
  <li><a href="https://requests.readthedocs.io/en/latest/user/quickstart/">Quickstart</a></li>
  <li><a href="https://requests.readthedocs.io/en/latest/user/advanced/">Advanced Usage</a></li>
  <li><a href="https://requests.readthedocs.io/en/latest/api/">API Reference</a></li>
  <li><a href="https://requests.readthedocs.io/en/latest/community/updates/#release-history">Release History</a></li>
  <li><a href="https://requests.readthedocs.io/en/latest/dev/contributing/">Contributors Guide</a></li>

  <p></p>

  <li><a href="https://requests.readthedocs.io/en/latest/community/recommended/">Recommended Packages and Extensions</a></li>

  <p></p>

  <li><a href="https://github.com/psf/requests">Requests @ GitHub</a></li>
  <li><a href="https://pypi.org/project/requests/">Requests @ PyPI</a></li>
  <li><a href="https://github.com/psf/requests/issues">Issue Tracker</a></li>
</ul>

<div id="native-ribbon">
</div>
